# 2022-03-25 - Liquidity Gauge Factory

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This relayer has been deprecated in favor of an [updated version](../../20220822-mainnet-gauge-factory-v2) with weight-capped gauges.

Deployment of the `LiquidityGaugeFactory`, for liquidity gauges to be used with pools on mainnet.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`LiquidityGaugeV5` artifact](./artifact/LiquidityGaugeV5.json)
- [`LiquidityGaugeFactory` artifact](./artifact/LiquidityGaugeFactory.json)
